---
layout: default
title: CAS - Web Flow Customization
---

# Webflow Session
CAS uses [Spring Webflow](https://github.com/spring-projects/spring-webflow) to manage the authentication sequence. Spring Webflow provides a pluggable architecture whereby various actions, decisions and operations throughout the primary authentication workflow can be easily controlled and navigated. In order for this navigation to work, some form of conversational session state must be maintained.

## Client-side Sessions
CAS provides a facility for storing flow execution state on the client in Spring Webflow. Flow state is stored as an encoded byte
stream in the flow execution identifier provided to the client when rendering a view.

CAS automatically attempts to store
and keep track of this state on the client in an encrypted form to remove the need for session cleanup, termination and replication.

Default encryption strategy controlled via the settings defined in the `application.properties` file:

```properties
# The encryption secret key. By default, must be a size 16.
# webflow.encryption.key=

# The signing secret key. By default, must be a octet string of size 512.
# webflow.signing.key=

# The algorithm used for secret keys
# webflow.secretkey.alg=AES
```


In the event that keys are not generated by the deployer, CAS will attempt to auto-generate keys and will output
the result for each respected key. The deployer MUST attempt to copy the generated keys over to the appropriate
settings in `application.properties`, specially when running a multi-node CAS deployment. Failure to do so will prevent CAS
to appropriate decrypt and encrypt the webflow state and will prevent successful single sign-on.

<div class="alert alert-warning"><strong>Usage Warning!</strong><p>
While the above settings are all optional, it is recommended that you provide your own configuration and settings for encrypting and
transcoding of the web session state.</p></div>

## Server-side Sessions

In the event that you wish to use server-side session storage for managing the webflow session, you will need to adjust
the following properties:

```properties
# webflow.session.storage=true
# webflow.session.lock.timeout=30
# webflow.session.max.conversations=5
# webflow.session.compress=false
```

Doing so will likely require you to also enable sticky sessions and/or session replication in a clustered deployment of CAS.

### Hazelast Session Replication

If you don't wish to use the native container's strategy for session replication, 
you can use CAS's support for Hazelcast session replication.

This feature is enabled via the following module:

```xml
<dependency>
  <groupId>org.apereo.cas</groupId>
  <artifactId>cas-server-webapp-session-hazelcast</artifactId>
  <version>${cas.version}</version>
</dependency>
```

The following settings are applicable:

```properties
# webflow.session.hz.location=classpath:/hazelcast.xml
```

### Redis Session Replication

If you don't wish to use the native container's strategy for session replication, 
you can use CAS's support for Redis session replication.

This feature is enabled via the following module:

```xml
<dependency>
  <groupId>org.apereo.cas</groupId>
  <artifactId>cas-server-webapp-session-redis</artifactId>
  <version>${cas.version}</version>
</dependency>
```

The following settings are applicable:

```properties
# spring.redis.host=pub-redis-16216.us-east-1-4.2.ec2.garantiadata.com
# spring.redis.password=cassession
# spring.redis.port=16216
```

### MongoDb Session Replication

If you don't wish to use the native container's strategy for session replication, 
you can use CAS's support for Mongo session replication.

This feature is enabled via the following module:

```xml
<dependency>
  <groupId>org.apereo.cas</groupId>
  <artifactId>cas-server-webapp-session-mongo</artifactId>
  <version>${cas.version}</version>
</dependency>
```

The following settings are applicable:

```properties
# spring.data.mongodb.host=
# spring.data.mongodb.username=
# spring.data.mongodb.password=
# spring.data.mongodb.port=
# spring.data.mongodb.database=
```
